const files = require("/usr/share/nginx/html/output.json");

module.exports = {
  // The viewports
  viewports: [
    {
      name: "mobile",
      width: 320,
      height: 480,
    },
    {
      name: "tablet",
      width: 768,
      height: 1024,
    },
    {
      name: "desktop",
      width: 1680,
      height: 1200,
    },
  ],
  engine: "puppeteer",
  engineOptions: {
    args: ["--no-sandbox"],
  },
  onReadyScript: "onReady.js",
  // Scenarios
  scenarios: getScenarios(),
  paths: {
    ci_report: "backstop_data/ci_report",
    engine_scripts: "engine_scripts",
  },
  report: ["browser", "CI"],
  ci: {
    format: "junit",
    testReportFileName: "myproject-xunit", // in case if you want to override the default filename (xunit.xml)
    testSuiteName: "backstopJS",
  },
};

/**
 * @returns {Array}
 */
function getScenarios() {
  const scenarios = [];

  files.forEach(({ path }) => {
    scenarios.push({
      delay: 1000,
      removeSelectors: [],
      label: path.replace("component-", "").replace(".html", ""),
      misMatchThreshold: 0.15,
      postInteractionWait: 500,
      url: `http://miyagi/${path}`,
    });
  });

  return scenarios;
}
